@@ -12,7 +12,6 @@ from icalendar.parser import Parameters
 from icalendar.parser import q_join
 from icalendar.parser import q_split
 from icalendar.parser_tools import DEFAULT_ENCODING
-from icalendar.parser_tools import data_encode
 from icalendar.prop import TypesFactory
 from icalendar.prop import vText, vDDDLists
 
@@ -30,7 +29,7 @@ class ComponentFactory(CaselessDict):
     def __init__(self, *args, **kwargs):
         """Set keys to upper for initial dict.
         """
-        CaselessDict.__init__(self, *args, **kwargs)
+        super(ComponentFactory, self).__init__(*args, **kwargs)
         self['VEVENT'] = Event
         self['VTODO'] = Todo
         self['VJOURNAL'] = Journal
@@ -44,9 +43,11 @@ class ComponentFactory(CaselessDict):
 
 # These Properties have multiple property values inlined in one propertyline
 # seperated by comma. Use CaselessDict as simple caseless set.
-INLINE = CaselessDict(
-    [(cat, 1) for cat in ('CATEGORIES', 'RESOURCES', 'FREEBUSY')]
-)
+INLINE = CaselessDict({
+    'CATEGORIES': 1,
+    'RESOURCES': 1,
+    'FREEBUSY': 1,
+})
 
 _marker = []
 
@@ -57,13 +58,13 @@ class Component(CaselessDict):
     directy, but rather one of the subclasses.
     """
 
-    name = ''        # must be defined in each component
-    required = ()    # These properties are required
-    singletons = ()  # These properties must only appear once
-    multiple = ()    # may occur more than once
-    exclusive = ()   # These properties are mutually exclusive
-    inclusive = ()   # if any occurs the other(s) MUST occur
-                     # ('duration', 'repeat')
+    name = None         # should be defined in each component
+    required = ()       # These properties are required
+    singletons = ()     # These properties must only appear once
+    multiple = ()       # may occur more than once
+    exclusive = ()      # These properties are mutually exclusive
+    inclusive = ()      # if any occurs the other(s) MUST occur
+                        # ('duration', 'repeat')
     ignore_exceptions = False   # if True, and we cannot parse this
                                 # component, we will silently ignore
                                 # it, rather than let the exception
@@ -73,7 +74,7 @@ class Component(CaselessDict):
     def __init__(self, *args, **kwargs):
         """Set keys to upper for initial dict.
         """
-        CaselessDict.__init__(self, *args, **kwargs)
+        super(Component, self).__init__(*args, **kwargs)
         # set parameters here for properties that use non-default values
         self.subcomponents = []  # Components can be nested.
         self.is_broken = False  # True if we ignored an exception while
@@ -172,7 +173,6 @@ class Component(CaselessDict):
         # set value
         if name in self:
             # If property already exists, append it.
-            #if name == 'attendee': import pdb; pdb.set_trace()
             oldval = self[name]
             if isinstance(oldval, list):
                 if isinstance(value, list):
@@ -261,20 +261,24 @@ class Component(CaselessDict):
         """Recursively traverses component and subcomponents. Returns sequence
         of same. If name is passed, only components with name will be returned.
         """
-        if not name is None:
+        if name is not None:
             name = name.upper()
         return self._walk(name)
 
     #####################
     # Generation
 
-    def property_items(self, recursive=True):
+    def property_items(self, recursive=True, sorted=True):
         """Returns properties in this component and subcomponents as:
         [(name, value), ...]
         """
         vText = types_factory['text']
         properties = [('BEGIN', vText(self.name).to_ical())]
-        property_names = self.sorted_keys()
+        if sorted:
+            property_names = self.sorted_keys()
+        else:
+            property_names = self.keys()
+
         for name in property_names:
             values = self[name]
             if isinstance(values, list):
@@ -286,7 +290,7 @@ class Component(CaselessDict):
         if recursive:
             # recursion is fun!
             for subcomponent in self.subcomponents:
-                properties += subcomponent.property_items()
+                properties += subcomponent.property_items(sorted=sorted)
         properties.append(('END', vText(self.name).to_ical()))
         return properties
 
@@ -299,7 +303,19 @@ class Component(CaselessDict):
         for line in Contentlines.from_ical(st):  # raw parsing
             if not line:
                 continue
-            name, params, vals = line.parts()
+
+            try:
+                name, params, vals = line.parts()
+            except ValueError:
+                # if unable to parse a line within a component
+                # that ignores exceptions, mark the component
+                # as broken and skip the line. otherwise raise.
+                component = stack[-1] if stack else None
+                if not component or not component.ignore_exceptions:
+                    raise
+                component.is_broken = True
+                continue
+
             uname = name.upper()
             # check for start of component
             if uname == 'BEGIN':
@@ -351,29 +367,41 @@ class Component(CaselessDict):
                              '{st!r}'.format(**locals()))
         return comps[0]
 
-    def __repr__(self):
-        return '%s(%s)' % (self.name, data_encode(self))
-
-    def content_line(self, name, value):
+    def content_line(self, name, value, sorted=True):
         """Returns property as content line.
         """
         params = getattr(value, 'params', Parameters())
-        return Contentline.from_parts(name, params, value)
+        return Contentline.from_parts(name, params, value, sorted=sorted)
 
-    def content_lines(self):
+    def content_lines(self, sorted=True):
         """Converts the Component and subcomponents into content lines.
         """
         contentlines = Contentlines()
-        for name, value in self.property_items():
-            cl = self.content_line(name, value)
+        for name, value in self.property_items(sorted=sorted):
+            cl = self.content_line(name, value, sorted=sorted)
             contentlines.append(cl)
         contentlines.append('')  # remember the empty string in the end
         return contentlines
 
-    def to_ical(self):
-        content_lines = self.content_lines()
+    def to_ical(self, sorted=True):
+        '''
+        :param sorted: Whether parameters and properties should be
+        lexicographically sorted.
+        '''
+
+        content_lines = self.content_lines(sorted=sorted)
         return content_lines.to_ical()
 
+    def __repr__(self):
+        """String representation of class with all of it's subcomponents.
+        """
+        subs = ', '.join([str(it) for it in self.subcomponents])
+        return '%s(%s%s)' % (
+            self.name,
+            dict(self),
+            ', %s' % subs if subs else ''
+        )
+
 
 #######################################
 # components defined in RFC 2445
