@@ -40,7 +40,12 @@ from datetime import datetime
 from datetime import time
 from datetime import timedelta
 from datetime import tzinfo
-from dateutil.tz import tzutc
+
+try:
+    from dateutil.tz import tzutc
+except ImportError:
+    tzutc = None
+
 from icalendar import compat
 from icalendar.caselessdict import CaselessDict
 from icalendar.parser import Parameters
@@ -151,7 +156,7 @@ class vBinary(object):
 class vBoolean(int):
     """Returns specific string according to state.
     """
-    BOOL_MAP = CaselessDict(true=True, false=False)
+    BOOL_MAP = CaselessDict({'true': True, 'false': False})
 
     def __new__(cls, *args, **kwargs):
         self = super(vBoolean, cls).__new__(cls, *args, **kwargs)
@@ -279,7 +284,8 @@ class vDDDTypes(object):
         if (isinstance(dt, datetime) or isinstance(dt, time))\
                 and getattr(dt, 'tzinfo', False):
             tzinfo = dt.tzinfo
-            if tzinfo is not pytz.utc and not isinstance(tzinfo, tzutc):
+            if tzinfo is not pytz.utc and\
+               (tzutc is None or not isinstance(tzinfo, tzutc)):
                 # set the timezone as a parameter to the property
                 tzid = tzid_from_dt(dt)
                 if tzid:
@@ -397,7 +403,7 @@ class vDatetime(object):
             elif not ical[15:]:
                 return datetime(*timetuple)
             elif ical[15:16] == 'Z':
-                return datetime(tzinfo=pytz.utc, *timetuple)
+                return pytz.utc.localize(datetime(*timetuple))
             else:
                 raise ValueError(ical)
         except:
@@ -629,7 +635,7 @@ class vRecur(CaselessDict):
     })
 
     def __init__(self, *args, **kwargs):
-        CaselessDict.__init__(self, *args, **kwargs)
+        super(vRecur, self).__init__(*args, **kwargs)
         self.params = Parameters()
 
     def to_ical(self):
@@ -778,7 +784,7 @@ class vUTCOffset(object):
 
         if self.td < timedelta(0):
             sign = '-%s'
-            td = timedelta(0)-self.td  # get timedelta relative to 0
+            td = timedelta(0) - self.td  # get timedelta relative to 0
         else:
             # Google Calendar rejects '0000' but accepts '+0000'
             sign = '+%s'
@@ -844,7 +850,7 @@ class TypesFactory(CaselessDict):
 
     def __init__(self, *args, **kwargs):
         "Set keys to upper for initial dict"
-        CaselessDict.__init__(self, *args, **kwargs)
+        super(TypesFactory, self).__init__(*args, **kwargs)
         self.all_types = (
             vBinary,
             vBoolean,
