@@ -180,6 +180,50 @@ END:VCALENDAR"""
         org_cn = cal.walk('VEVENT')[0]['ORGANIZER'].params['CN']
         self.assertEqual(org_cn, u'acme, ädmin')
 
+    def test_issue_104__ignore_exceptions(self):
+        """
+        Issue #104 - line parsing error in a VEVENT
+        (which has ignore_exceptions). Should mark the event broken
+        but not raise an exception.
+        https://github.com/collective/icalendar/issues/104
+        """
+        ical_str = """
+BEGIN:VEVENT
+DTSTART:20140401T000000Z
+DTEND:20140401T010000Z
+DTSTAMP:20140401T000000Z
+SUMMARY:Broken Eevnt
+CLASS:PUBLIC
+STATUS:CONFIRMED
+TRANSP:OPAQUE
+X
+END:VEVENT"""
+        event = icalendar.Calendar.from_ical(ical_str)
+        self.assertTrue(isinstance(event, icalendar.Event))
+        self.assertTrue(event.is_broken)
+
+    def test_issue_104__no_ignore_exceptions(self):
+        """
+        Issue #104 - line parsing error in a VCALENDAR
+        (which doesn't have ignore_exceptions). Should raise an exception.
+        """
+        ical_str = """BEGIN:VCALENDAR
+VERSION:2.0
+METHOD:PUBLISH
+BEGIN:VEVENT
+DTSTART:20140401T000000Z
+DTEND:20140401T010000Z
+DTSTAMP:20140401T000000Z
+SUMMARY:Broken Eevnt
+CLASS:PUBLIC
+STATUS:CONFIRMED
+TRANSP:OPAQUE
+END:VEVENT
+X
+END:VCALENDAR"""
+        with self.assertRaises(ValueError):
+            icalendar.Calendar.from_ical(ical_str)
+
     def test_issue_112(self):
         """Issue #112 - No timezone info on EXDATE
         https://github.com/collective/icalendar/issues/112
@@ -206,20 +250,10 @@ END:VCALENDAR"""
 
             self.assertEqual(event['exdate'][0].dts[0].dt.tzname(), 'EDT')
 
-    def test_issue_114(self):
-        """Issue #114/#115 - invalid line in event breaks the parser
-        https://github.com/collective/icalendar/issues/114
-        """
-
-        directory = os.path.dirname(__file__)
-        ics = open(os.path.join(directory, 'issue_114_invalid_line.ics'), 'rb')
-        with self.assertRaises(ValueError):
-            cal = icalendar.Calendar.from_ical(ics.read())
-            cal  # pep 8
-        ics.close()
-
     def test_issue_116(self):
         """Issue #116/#117 - How to add 'X-APPLE-STRUCTURED-LOCATION'
+        https://github.com/collective/icalendar/issues/116
+        https://github.com/collective/icalendar/issues/117
         """
         event = icalendar.Event()
         event.add(
@@ -245,3 +279,40 @@ END:VCALENDAR"""
             event.to_ical(),
             icalendar.Event.from_ical(event.to_ical()).to_ical()
         )
+
+    def test_issue_142(self):
+        """Issue #142 - Multivalued parameters
+        This is needed for VCard 3.0.
+        https://github.com/collective/icalendar/pull/142
+        """
+        from icalendar.parser import Contentline, Parameters
+
+        ctl = Contentline.from_ical("TEL;TYPE=HOME,VOICE:000000000")
+
+        self.assertEqual(
+            ctl.parts(),
+            (u'TEL', Parameters({'TYPE': ['HOME', 'VOICE']}), u'000000000'),
+        )
+
+    def test_issue_143(self):
+        """Issue #143 - Allow dots in property names.
+        Another vCard related issue.
+        https://github.com/collective/icalendar/pull/143
+        """
+        from icalendar.parser import Contentline, Parameters
+
+        ctl = Contentline.from_ical("ITEMADRNULLTHISISTHEADRESS08158SOMECITY12345.ADR:;;This is the Adress 08; Some City;;12345;Germany")  # nopep8
+        self.assertEqual(
+            ctl.parts(),
+            (u'ITEMADRNULLTHISISTHEADRESS08158SOMECITY12345.ADR',
+             Parameters(),
+             u';;This is the Adress 08; Some City;;12345;Germany'),
+        )
+
+        ctl2 = Contentline.from_ical("ITEMADRNULLTHISISTHEADRESS08158SOMECITY12345.X-ABLABEL:")  # nopep8
+        self.assertEqual(
+            ctl2.parts(),
+            (u'ITEMADRNULLTHISISTHEADRESS08158SOMECITY12345.X-ABLABEL',
+             Parameters(),
+             u''),
+        )
