@@ -100,7 +100,7 @@ class TestProp(unittest.TestCase):
                                    datetime))
 
         self.assertEqual(vDDDTypes.from_ical('20010101T123000Z'),
-                         datetime(2001, 1, 1, 12, 30, tzinfo=pytz.utc))
+                         pytz.utc.localize(datetime(2001, 1, 1, 12, 30)))
 
         self.assertTrue(isinstance(vDDDTypes.from_ical('20010101'), date))
 
@@ -130,10 +130,10 @@ class TestProp(unittest.TestCase):
         self.assertEqual(vDatetime.from_ical('20000101T120000'),
                          datetime(2000, 1, 1, 12, 0))
 
-        dutc = datetime(2001, 1, 1, 12, 30, 0, tzinfo=pytz.utc)
+        dutc = pytz.utc.localize(datetime(2001, 1, 1, 12, 30, 0))
         self.assertEqual(vDatetime(dutc).to_ical(), b'20010101T123000Z')
 
-        dutc = datetime(1899, 1, 1, 12, 30, 0, tzinfo=pytz.utc)
+        dutc = pytz.utc.localize(datetime(1899, 1, 1, 12, 30, 0))
         self.assertEqual(vDatetime(dutc).to_ical(), b'18990101T123000Z')
 
         self.assertEqual(vDatetime.from_ical('20010101T000000'),
@@ -222,15 +222,15 @@ class TestProp(unittest.TestCase):
 
         # Timezoned
         dk = pytz.timezone('Europe/Copenhagen')
-        start = datetime(2000, 1, 1, tzinfo=dk)
-        end = datetime(2000, 1, 2, tzinfo=dk)
+        start = dk.localize(datetime(2000, 1, 1))
+        end = dk.localize(datetime(2000, 1, 2))
         per = (start, end)
         self.assertEqual(vPeriod(per).to_ical(),
                          b'20000101T000000/20000102T000000')
         self.assertEqual(vPeriod(per).params['TZID'],
                          'Europe/Copenhagen')
 
-        p = vPeriod((datetime(2000, 1, 1, tzinfo=dk), timedelta(days=31)))
+        p = vPeriod((dk.localize(datetime(2000, 1, 1)), timedelta(days=31)))
         self.assertEqual(p.to_ical(), b'20000101T000000/P31D')
 
     def test_prop_vWeekday(self):
