@@ -1,14 +1,11 @@
-from __future__ import absolute_import
-import random
-from string import (
-    ascii_letters,
-    digits,
-)
 from datetime import datetime
-from .prop import (
-    vText,
-    vDatetime,
-)
+from icalendar.parser_tools import to_unicode
+from icalendar.prop import vDatetime
+from icalendar.prop import vText
+from string import ascii_letters
+from string import digits
+
+import random
 
 
 class UIDGenerator(object):
@@ -28,7 +25,9 @@ class UIDGenerator(object):
         Like:
             20050105T225746Z-HKtJMqUgdO0jDUwm@example.com
         """
+        host_name = to_unicode(host_name)
         unique = unique or self.rnd_string()
-        return vText('%s-%s@%s' % (vDatetime(datetime.today()).to_ical(),
+        today = to_unicode(vDatetime(datetime.today()).to_ical())
+        return vText('%s-%s@%s' % (today,
                                    unique,
                                    host_name))
